@@ -1,14 +1,15 @@
 // defaults.h.in
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002,
+              2003, 2004, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,9 +17,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -30,7 +30,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "pathsearch.h"
 
 #ifndef OCTAVE_CANONICAL_HOST_TYPE
-#define OCTAVE_CANONICAL_HOST_TYPE "i386-unknown-openbsd3.9"
+#define OCTAVE_CANONICAL_HOST_TYPE "i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_DEFAULT_PAGER
@@ -38,7 +38,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #endif
 
 #ifndef OCTAVE_ARCHLIBDIR
-#define OCTAVE_ARCHLIBDIR "/usr/local/libexec/octave/2.1.72/exec/i386-unknown-openbsd3.9"
+#define OCTAVE_ARCHLIBDIR "/usr/local/libexec/octave/3.0.0/exec/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_BINDIR
@@ -49,24 +49,20 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #define OCTAVE_DATADIR "/usr/local/share"
 #endif
 
+#ifndef OCTAVE_DATAROOTDIR
+#define OCTAVE_DATAROOTDIR "/usr/local/share"
+#endif
+
 #ifndef OCTAVE_EXEC_PREFIX
 #define OCTAVE_EXEC_PREFIX "/usr/local"
 #endif
 
 #ifndef OCTAVE_FCNFILEDIR
-#define OCTAVE_FCNFILEDIR "/usr/local/share/octave/2.1.72/m"
-#endif
-
-#ifndef OCTAVE_FCNFILEPATH
-#define OCTAVE_FCNFILEPATH ".:/usr/local/libexec/octave/2.1.72/site/oct/i386-unknown-openbsd3.9//:/usr/local/libexec/octave/site/oct/api-v13/i386-unknown-openbsd3.9//:/usr/local/libexec/octave/site/oct/i386-unknown-openbsd3.9//:/usr/local/share/octave/2.1.72/site/m//:/usr/local/share/octave/site/api-v13/m//:/usr/local/share/octave/site/m//:/usr/local/libexec/octave/2.1.72/oct/i386-unknown-openbsd3.9//:/usr/local/share/octave/2.1.72/m//"
+#define OCTAVE_FCNFILEDIR "/usr/local/share/octave/3.0.0/m"
 #endif
 
 #ifndef OCTAVE_IMAGEDIR
-#define OCTAVE_IMAGEDIR "/usr/local/share/octave/2.1.72/imagelib"
-#endif
-
-#ifndef OCTAVE_IMAGEPATH
-#define OCTAVE_IMAGEPATH ".:/usr/local/share/octave/2.1.72/imagelib//"
+#define OCTAVE_IMAGEDIR "/usr/local/share/octave/3.0.0/imagelib"
 #endif
 
 #ifndef OCTAVE_INCLUDEDIR
@@ -94,47 +90,43 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #endif
 
 #ifndef OCTAVE_LOCALAPIFCNFILEDIR
-#define OCTAVE_LOCALAPIFCNFILEDIR "/usr/local/share/octave/site/api-v13/m"
+#define OCTAVE_LOCALAPIFCNFILEDIR "/usr/local/share/octave/site/api-v32/m"
 #endif
 
 #ifndef OCTAVE_LOCALAPIOCTFILEDIR
-#define OCTAVE_LOCALAPIOCTFILEDIR "/usr/local/libexec/octave/site/oct/api-v13/i386-unknown-openbsd3.9"
+#define OCTAVE_LOCALAPIOCTFILEDIR "/usr/local/libexec/octave/site/oct/api-v32/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_LOCALARCHLIBDIR
-#define OCTAVE_LOCALARCHLIBDIR "/usr/local/libexec/octave/site/exec/i386-unknown-openbsd3.9"
+#define OCTAVE_LOCALARCHLIBDIR "/usr/local/libexec/octave/site/exec/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_LOCALFCNFILEDIR
 #define OCTAVE_LOCALFCNFILEDIR "/usr/local/share/octave/site/m"
 #endif
 
-#ifndef OCTAVE_LOCALFCNFILEPATH
-#define OCTAVE_LOCALFCNFILEPATH "/usr/local/share/octave/2.1.72/site/m//:/usr/local/share/octave/site/api-v13/m//:/usr/local/share/octave/site/m//"
-#endif
-
 #ifndef OCTAVE_LOCALOCTFILEDIR
-#define OCTAVE_LOCALOCTFILEDIR "/usr/local/libexec/octave/site/oct/i386-unknown-openbsd3.9"
-#endif
-
-#ifndef OCTAVE_LOCALOCTFILEPATH
-#define OCTAVE_LOCALOCTFILEPATH "/usr/local/libexec/octave/2.1.72/site/oct/i386-unknown-openbsd3.9//:/usr/local/libexec/octave/site/oct/api-v13/i386-unknown-openbsd3.9//:/usr/local/libexec/octave/site/oct/i386-unknown-openbsd3.9//"
+#define OCTAVE_LOCALOCTFILEDIR "/usr/local/libexec/octave/site/oct/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_LOCALSTARTUPFILEDIR
 #define OCTAVE_LOCALSTARTUPFILEDIR "/usr/local/share/octave/site/m/startup"
 #endif
 
+#ifndef OCTAVE_LOCALAPIARCHLIBDIR
+#define OCTAVE_LOCALAPIARCHLIBDIR "/usr/local/libexec/octave/api-v32/site/exec/i386-unknown-openbsd4.3"
+#endif
+
 #ifndef OCTAVE_LOCALVERARCHLIBDIR
-#define OCTAVE_LOCALVERARCHLIBDIR "/usr/local/libexec/octave/2.1.72/site/exec/i386-unknown-openbsd3.9"
+#define OCTAVE_LOCALVERARCHLIBDIR "/usr/local/libexec/octave/3.0.0/site/exec/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_LOCALVERFCNFILEDIR
-#define OCTAVE_LOCALVERFCNFILEDIR "/usr/local/share/octave/2.1.72/site/m"
+#define OCTAVE_LOCALVERFCNFILEDIR "/usr/local/share/octave/3.0.0/site/m"
 #endif
 
 #ifndef OCTAVE_LOCALVEROCTFILEDIR
-#define OCTAVE_LOCALVEROCTFILEDIR "/usr/local/libexec/octave/2.1.72/site/oct/i386-unknown-openbsd3.9"
+#define OCTAVE_LOCALVEROCTFILEDIR "/usr/local/libexec/octave/3.0.0/site/oct/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_MAN1DIR
@@ -150,11 +142,11 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #endif
 
 #ifndef OCTAVE_OCTFILEDIR
-#define OCTAVE_OCTFILEDIR "/usr/local/libexec/octave/2.1.72/oct/i386-unknown-openbsd3.9"
+#define OCTAVE_OCTFILEDIR "/usr/local/libexec/octave/3.0.0/oct/i386-unknown-openbsd4.3"
 #endif
 
 #ifndef OCTAVE_OCTINCLUDEDIR
-#define OCTAVE_OCTINCLUDEDIR "/usr/local/include/octave-2.1.72"
+#define OCTAVE_OCTINCLUDEDIR "/usr/local/include/octave-3.0.0"
 #endif
 
 #ifndef OCTAVE_OCTLIBDIR
@@ -166,7 +158,11 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #endif
 
 #ifndef OCTAVE_STARTUPFILEDIR
-#define OCTAVE_STARTUPFILEDIR "/usr/local/share/octave/2.1.72/m/startup"
+#define OCTAVE_STARTUPFILEDIR "/usr/local/share/octave/3.0.0/m/startup"
+#endif
+
+#ifndef OCTAVE_RELEASE
+#define OCTAVE_RELEASE ""
 #endif
 
 extern std::string Voctave_home;
@@ -178,32 +174,36 @@ extern std::string Vlibexec_dir;
 extern std::string Varch_lib_dir;
 extern std::string Vlocal_arch_lib_dir;
 extern std::string Vlocal_ver_arch_lib_dir;
+
+extern std::string Vlocal_ver_oct_file_dir;
+extern std::string Vlocal_api_oct_file_dir;
+extern std::string Vlocal_oct_file_dir;
+
+extern std::string Vlocal_ver_fcn_file_dir;
+extern std::string Vlocal_api_fcn_file_dir;
+extern std::string Vlocal_fcn_file_dir;
+
+extern std::string Voct_file_dir;
 extern std::string Vfcn_file_dir;
 
-// The path that will be searched for programs that we execute.
-// (--exec-path path)
-extern std::string Vexec_path;
-
-// And the cached directory path corresponding to Vload_path.
-extern dir_path Vload_path_dir_path;
+extern std::string Vimage_dir;
 
 // Name of the editor to be invoked by the edit_history command.
-extern std::string Veditor;
-
-extern std::string Vimagepath;
+extern std::string VEDITOR;
 
 extern std::string Vlocal_site_defaults_file;
 extern std::string Vsite_defaults_file;
 
 // Name of the FFTW wisdom program.
-extern std::string Vfftw_wisdom_prog;
+extern OCTINTERP_API std::string Vfftw_wisdom_program;
 
-extern void execute_default_pkg_add_files (void);
-
-extern std::string maybe_add_default_load_path (const std::string& pathstring);
+extern std::string subst_octave_home (const std::string&);
 
 extern void install_defaults (void);
 
+extern void set_exec_path (const std::string& path = std::string ());
+extern void set_image_path (const std::string& path = std::string ());
+
 #endif
 
 /*
